@@ -51,7 +51,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
 
 
 @jsii.data_type(
@@ -68,10 +68,10 @@ class FckNatInstanceProps:
     def __init__(
         self,
         *,
-        instance_type: aws_cdk.aws_ec2.InstanceType,
+        instance_type: _aws_cdk_aws_ec2_ceddda9d.InstanceType,
         key_name: typing.Optional[builtins.str] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
     ) -> None:
         '''Properties for a fck-nat instance.
 
@@ -81,20 +81,12 @@ class FckNatInstanceProps:
         :param security_group: Security Group for fck-nat instances. Default: - A new security group will be created
         '''
         if __debug__:
-            def stub(
-                *,
-                instance_type: aws_cdk.aws_ec2.InstanceType,
-                key_name: typing.Optional[builtins.str] = None,
-                machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-                security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c4557b0164d909dd1470d454a4f5d57f3ed9a34033b627565f2c5265d5d68c85)
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument key_name", value=key_name, expected_type=type_hints["key_name"])
             check_type(argname="argument machine_image", value=machine_image, expected_type=type_hints["machine_image"])
             check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "instance_type": instance_type,
         }
         if key_name is not None:
@@ -105,11 +97,11 @@ class FckNatInstanceProps:
             self._values["security_group"] = security_group
 
     @builtins.property
-    def instance_type(self) -> aws_cdk.aws_ec2.InstanceType:
+    def instance_type(self) -> _aws_cdk_aws_ec2_ceddda9d.InstanceType:
         '''Instance type of the fck-nat instance.'''
         result = self._values.get("instance_type")
         assert result is not None, "Required property 'instance_type' is missing"
-        return typing.cast(aws_cdk.aws_ec2.InstanceType, result)
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.InstanceType, result)
 
     @builtins.property
     def key_name(self) -> typing.Optional[builtins.str]:
@@ -121,7 +113,7 @@ class FckNatInstanceProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def machine_image(self) -> typing.Optional[aws_cdk.aws_ec2.IMachineImage]:
+    def machine_image(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage]:
         '''The machine image (AMI) to use.
 
         By default, will do an AMI lookup for the latest fck-nat instance image.
@@ -139,16 +131,18 @@ class FckNatInstanceProps:
         :default: - Latest fck-nat instance image
         '''
         result = self._values.get("machine_image")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IMachineImage], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage], result)
 
     @builtins.property
-    def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
+    def security_group(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]:
         '''Security Group for fck-nat instances.
 
         :default: - A new security group will be created
         '''
         result = self._values.get("security_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISecurityGroup], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -162,19 +156,19 @@ class FckNatInstanceProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_ec2.IConnectable)
+@jsii.implements(_aws_cdk_aws_ec2_ceddda9d.IConnectable)
 class FckNatInstanceProvider(
-    aws_cdk.aws_ec2.NatProvider,
+    _aws_cdk_aws_ec2_ceddda9d.NatProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-fck-nat.FckNatInstanceProvider",
 ):
     def __init__(
         self,
         *,
-        instance_type: aws_cdk.aws_ec2.InstanceType,
+        instance_type: _aws_cdk_aws_ec2_ceddda9d.InstanceType,
         key_name: typing.Optional[builtins.str] = None,
-        machine_image: typing.Optional[aws_cdk.aws_ec2.IMachineImage] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
+        machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+        security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
     ) -> None:
         '''
         :param instance_type: Instance type of the fck-nat instance.
@@ -195,9 +189,9 @@ class FckNatInstanceProvider(
     def configure_nat(
         self,
         *,
-        nat_subnets: typing.Sequence[aws_cdk.aws_ec2.PublicSubnet],
-        private_subnets: typing.Sequence[aws_cdk.aws_ec2.PrivateSubnet],
-        vpc: aws_cdk.aws_ec2.Vpc,
+        nat_subnets: typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+        private_subnets: typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet],
+        vpc: _aws_cdk_aws_ec2_ceddda9d.Vpc,
     ) -> None:
         '''Called by the VPC to configure NAT.
 
@@ -207,14 +201,14 @@ class FckNatInstanceProvider(
         :param private_subnets: The private subnets that need to route through the NAT providers. There may be more private subnets than public subnets with NAT providers.
         :param vpc: The VPC we're configuring NAT for.
         '''
-        options = aws_cdk.aws_ec2.ConfigureNatOptions(
+        options = _aws_cdk_aws_ec2_ceddda9d.ConfigureNatOptions(
             nat_subnets=nat_subnets, private_subnets=private_subnets, vpc=vpc
         )
 
         return typing.cast(None, jsii.invoke(self, "configureNat", [options]))
 
     @jsii.member(jsii_name="configureSubnet")
-    def configure_subnet(self, subnet: aws_cdk.aws_ec2.PrivateSubnet) -> None:
+    def configure_subnet(self, subnet: _aws_cdk_aws_ec2_ceddda9d.PrivateSubnet) -> None:
         '''Configures subnet with the gateway.
 
         Don't call this directly, the VPC will call it automatically.
@@ -222,29 +216,29 @@ class FckNatInstanceProvider(
         :param subnet: -
         '''
         if __debug__:
-            def stub(subnet: aws_cdk.aws_ec2.PrivateSubnet) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2530e48e0fe57e3382c88c654d9132a4425b047a1cbece5fb1b57592d62710ba)
             check_type(argname="argument subnet", value=subnet, expected_type=type_hints["subnet"])
         return typing.cast(None, jsii.invoke(self, "configureSubnet", [subnet]))
 
     @builtins.property
     @jsii.member(jsii_name="configuredGateways")
-    def configured_gateways(self) -> typing.List[aws_cdk.aws_ec2.GatewayConfig]:
+    def configured_gateways(
+        self,
+    ) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.GatewayConfig]:
         '''Return list of gateways spawned by the provider.'''
-        return typing.cast(typing.List[aws_cdk.aws_ec2.GatewayConfig], jsii.get(self, "configuredGateways"))
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.GatewayConfig], jsii.get(self, "configuredGateways"))
 
     @builtins.property
     @jsii.member(jsii_name="connections")
-    def connections(self) -> aws_cdk.aws_ec2.Connections:
+    def connections(self) -> _aws_cdk_aws_ec2_ceddda9d.Connections:
         '''Manage the Security Groups associated with the NAT instances.'''
-        return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.Connections, jsii.get(self, "connections"))
 
     @builtins.property
     @jsii.member(jsii_name="securityGroup")
-    def security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
+    def security_group(self) -> _aws_cdk_aws_ec2_ceddda9d.ISecurityGroup:
         '''The Security Group associated with the NAT instances.'''
-        return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "securityGroup"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup, jsii.get(self, "securityGroup"))
 
 
 __all__ = [
@@ -253,3 +247,19 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c4557b0164d909dd1470d454a4f5d57f3ed9a34033b627565f2c5265d5d68c85(
+    *,
+    instance_type: _aws_cdk_aws_ec2_ceddda9d.InstanceType,
+    key_name: typing.Optional[builtins.str] = None,
+    machine_image: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IMachineImage] = None,
+    security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2530e48e0fe57e3382c88c654d9132a4425b047a1cbece5fb1b57592d62710ba(
+    subnet: _aws_cdk_aws_ec2_ceddda9d.PrivateSubnet,
+) -> None:
+    """Type checking stubs"""
+    pass
